==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/pt_br/admin_departments.php <==
<?php
/**
 * Admin Departments
 *
 * @package blesta
 * @subpackage blesta.language.pt_br
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminDepartments.edit.text_add'] = 'Adicionar';
$lang['AdminDepartments.edit.text_delete'] = 'Excluir';
$lang['AdminDepartments.edit.heading_default'] = 'Padrão';
$lang['AdminDepartments.edit.heading_value'] = 'Valor';
$lang['AdminDepartments.edit.heading_name'] = 'Nome';
$lang['AdminDepartments.edit.heading_options'] = 'Opções';
$lang['AdminDepartments.edit.heading_auto_delete'] = 'Auto-Delete (exclusão automática)';
$lang['AdminDepartments.edit.heading_encrypted'] = 'Criptografado';
$lang['AdminDepartments.edit.heading_client_add'] = 'O cliente pode adicionar';
$lang['AdminDepartments.edit.heading_step'] = 'Etapa';
$lang['AdminDepartments.edit.heading_max'] = 'Máximo';
$lang['AdminDepartments.edit.heading_min'] = 'Mínimo';
$lang['AdminDepartments.edit.heading_type'] = 'Tipo';
$lang['AdminDepartments.edit.heading_visibility'] = 'Visibilidade';
$lang['AdminDepartments.edit.heading_description'] = 'Descrição';
$lang['AdminDepartments.edit.heading_label'] = 'Rótulo';
$lang['AdminDepartments.edit.no_results'] = 'Não há campos personalizados nesse departamento.';
$lang['AdminDepartments.edit.confirm_field_remove'] = 'Tem certeza de que deseja excluir esse campo personalizado? Todos os dados associados a esse campo serão excluídos. Se você quiser ocultar esse campo e preservar os dados, altere sua Visibilidade para Staff Only (Somente equipe).';
$lang['AdminDepartments.edit.field_add_field'] = 'Adicionar campo';
$lang['AdminDepartments.edit.field_addsubmit'] = 'Departamento de Edição';
$lang['AdminDepartments.edit.field_status'] = 'Status';
$lang['AdminDepartments.edit.field_response_id'] = 'Resposta de fechamento automático de tíquete';
$lang['AdminDepartments.edit.field_reminder_ticket_priority'] = 'Enviar lembretes para tickets com prioridade';
$lang['AdminDepartments.edit.field_reminder_ticket_status'] = 'Enviar lembretes para tickets com status';
$lang['AdminDepartments.edit.field_reminder_ticket_interval'] = 'Enviar automaticamente lembretes de tíquetes';
$lang['AdminDepartments.edit.field_delete_ticket_interval'] = 'Exclusão automática de tickets';
$lang['AdminDepartments.edit.field_close_ticket_interval'] = 'Fechamento automático de tickets';
$lang['AdminDepartments.edit.field_port'] = 'Porto';
$lang['AdminDepartments.edit.field_pass'] = 'Passe';
$lang['AdminDepartments.edit.field_user'] = 'Usuário';
$lang['AdminDepartments.edit.field_host'] = 'Anfitrião';
$lang['AdminDepartments.edit.field_mark_messages'] = 'Marcar mensagens como';
$lang['AdminDepartments.edit.field_box_name'] = 'Nome da caixa';
$lang['AdminDepartments.edit.field_security'] = 'Segurança';
$lang['AdminDepartments.edit.field_max_attachment_size'] = 'Tamanho máximo do acessório';
$lang['AdminDepartments.edit.field_attachment_types'] = 'Tipos de anexos suportados';
$lang['AdminDepartments.edit.field_include_attachments'] = 'Incluir anexos compatíveis em avisos de tíquetes';
$lang['AdminDepartments.edit.field_default_priority'] = 'Prioridade padrão';
$lang['AdminDepartments.edit.field_piping_config'] = 'Configuração de tubulação';
$lang['AdminDepartments.edit.field_method'] = 'Tratamento de e-mails';
$lang['AdminDepartments.edit.field_automatic_transition'] = 'Transição automática do status do tíquete na resposta do administrador';
$lang['AdminDepartments.edit.field_send_ticket_received'] = 'Enviar e-mails de resposta automática para novos tíquetes';
$lang['AdminDepartments.edit.field_override_from_email'] = 'Substituir o endereço de origem definido nos modelos de e-mail pelo endereço de e-mail definido para esse departamento';
$lang['AdminDepartments.edit.field_email'] = 'E-mail';
$lang['AdminDepartments.edit.field_require_captcha'] = 'Exigir verificação humana para usuários não autenticados';
$lang['AdminDepartments.edit.field_clients_only'] = 'Permitir que apenas clientes abram ou respondam a tíquetes';
$lang['AdminDepartments.edit.field_description'] = 'Descrição';
$lang['AdminDepartments.edit.field_name'] = 'Nome';
$lang['AdminDepartments.edit.tab_custom_fields'] = 'Campos personalizados';
$lang['AdminDepartments.edit.tab_general'] = 'Geral';
$lang['AdminDepartments.edit.boxtitle_adddepartment'] = 'Departamento de Edição';
$lang['AdminDepartments.add.text_add'] = 'Adicionar';
$lang['AdminDepartments.add.text_delete'] = 'Excluir';
$lang['AdminDepartments.add.heading_default'] = 'Padrão';
$lang['AdminDepartments.add.heading_value'] = 'Valor';
$lang['AdminDepartments.add.heading_name'] = 'Nome';
$lang['AdminDepartments.add.heading_options'] = 'Opções';
$lang['AdminDepartments.add.heading_auto_delete'] = 'Auto-Delete (exclusão automática)';
$lang['AdminDepartments.add.heading_encrypted'] = 'Criptografado';
$lang['AdminDepartments.add.heading_client_add'] = 'O cliente pode adicionar';
$lang['AdminDepartments.add.heading_step'] = 'Etapa';
$lang['AdminDepartments.add.heading_max'] = 'Máximo';
$lang['AdminDepartments.add.heading_min'] = 'Mínimo';
$lang['AdminDepartments.add.heading_type'] = 'Tipo';
$lang['AdminDepartments.add.heading_visibility'] = 'Visibilidade';
$lang['AdminDepartments.add.heading_description'] = 'Descrição';
$lang['AdminDepartments.add.heading_label'] = 'Rótulo';
$lang['AdminDepartments.add.field_add_field'] = 'Adicionar campo';
$lang['AdminDepartments.add.field_addsubmit'] = 'Adicionar departamento';
$lang['AdminDepartments.add.field_status'] = 'Status';
$lang['AdminDepartments.add.field_response_id'] = 'Resposta de fechamento automático de tíquete';
$lang['AdminDepartments.add.field_reminder_ticket_priority'] = 'Enviar lembretes para tickets com prioridade';
$lang['AdminDepartments.add.field_reminder_ticket_status'] = 'Enviar lembretes para tickets com status';
$lang['AdminDepartments.add.field_reminder_ticket_interval'] = 'Enviar automaticamente lembretes de tíquetes';
$lang['AdminDepartments.add.field_delete_ticket_interval'] = 'Exclusão automática de tickets';
$lang['AdminDepartments.add.field_close_ticket_interval'] = 'Fechamento automático de tickets';
$lang['AdminDepartments.add.field_port'] = 'Porto';
$lang['AdminDepartments.add.field_pass'] = 'Passe';
$lang['AdminDepartments.add.field_user'] = 'Usuário';
$lang['AdminDepartments.add.field_host'] = 'Anfitrião';
$lang['AdminDepartments.add.field_mark_messages'] = 'Marcar mensagens como';
$lang['AdminDepartments.add.field_box_name'] = 'Nome da caixa';
$lang['AdminDepartments.add.field_security'] = 'Segurança';
$lang['AdminDepartments.add.field_max_attachment_size'] = 'Tamanho máximo do acessório';
$lang['AdminDepartments.add.field_attachment_types'] = 'Tipos de anexos suportados';
$lang['AdminDepartments.add.field_include_attachments'] = 'Incluir anexos compatíveis em avisos de tíquetes';
$lang['AdminDepartments.add.field_default_priority'] = 'Prioridade padrão';
$lang['AdminDepartments.add.field_piping_config'] = 'Configuração de tubulação';
$lang['AdminDepartments.add.field_method'] = 'Tratamento de e-mails';
$lang['AdminDepartments.add.field_automatic_transition'] = 'Transição automática do status do tíquete na resposta do administrador';
$lang['AdminDepartments.add.field_send_ticket_received'] = 'Enviar e-mails de resposta automática para novos tíquetes';
$lang['AdminDepartments.add.field_override_from_email'] = 'Substituir o endereço de origem definido nos modelos de e-mail pelo endereço de e-mail definido para esse departamento';
$lang['AdminDepartments.add.field_email'] = 'E-mail';
$lang['AdminDepartments.add.field_require_captcha'] = 'Exigir verificação humana para usuários não autenticados';
$lang['AdminDepartments.add.field_clients_only'] = 'Permitir que apenas clientes abram ou respondam a tíquetes';
$lang['AdminDepartments.add.field_description'] = 'Descrição';
$lang['AdminDepartments.add.field_name'] = 'Nome';
$lang['AdminDepartments.add.tab_custom_fields'] = 'Campos personalizados';
$lang['AdminDepartments.add.tab_general'] = 'Geral';
$lang['AdminDepartments.add.boxtitle_adddepartment'] = 'Adicionar departamento';
$lang['AdminDepartments.!text.remove_response'] = 'Remover';
$lang['AdminDepartments.!text.no_selected_response'] = 'Nenhuma resposta de fechamento automático foi selecionada.';
$lang['AdminDepartments.!text.add_response'] = 'Definir uma resposta predefinida de fechamento automático';
$lang['AdminDepartments.!tooltip.auto_delete'] = 'Se o tíquete for fechado, os dados do campo serão excluídos automaticamente. Os dados não estarão mais visíveis para a equipe.';
$lang['AdminDepartments.!tooltip.client_add'] = 'Se o cliente pode ou não enviar o campo; se for falso, o cliente só poderá ler o campo.';
$lang['AdminDepartments.!tooltip.max_attachment_size'] = 'Tamanho máximo do anexo a ser incluído em MB.';
$lang['AdminDepartments.!tooltip.attachment_types'] = 'Lista de extensões compatíveis separadas por vírgula (por exemplo, zip, jpg, png).';
$lang['AdminDepartments.!tooltip.include_attachments'] = 'Os servidores de e-mail têm limitações quanto ao tamanho dos anexos e aos tipos de arquivos. Para reduzir o risco de rejeição do e-mail, inclua limitações de tipo e tamanho de anexo. Para ter certeza de que o cliente está ciente dos anexos que não foram incluídos, use a tag {ticket.reply_has_attachments} nos avisos de tíquetes.';
$lang['AdminDepartments.!tooltip.automatic_transition'] = 'Altera o status para %1$s quando um membro da equipe responde.';
$lang['AdminDepartments.!tooltip.send_ticket_received'] = 'A desmarcação dessa caixa indica que os novos tíquetes criados para esse departamento (por e-mail ou cliente) não enviarão um aviso de resposta ao cliente ou à equipe por meio do e-mail Ticket Received (Tíquete recebido) ou do e-mail Staff Ticket Updated (Tíquete da equipe atualizado), respectivamente.';
$lang['AdminDepartments.!tooltip.reminder_ticket_interval'] = 'Para todos os tickets com status diferente de %1$s, um lembrete será enviado para a outra parte se nenhuma resposta for dada dentro do período de tempo selecionado.';
$lang['AdminDepartments.!tooltip.delete_ticket_interval'] = 'Todos os tickets com status de %1$s serão automaticamente apagados após permanecerem nesse status pelo período de tempo selecionado.';
$lang['AdminDepartments.!tooltip.close_ticket_interval'] = 'Todos os tickets com status diferente de %1$s cuja última resposta for de um membro da equipe serão fechados automaticamente se nenhuma resposta for dada dentro do período de tempo selecionado.';
$lang['AdminDepartments.!tooltip.piping_config'] = 'Defina o caminho do piping conforme mostrado, mas certifique-se de usar o caminho correto para o PHP em seu servidor. Certifique-se de que o pipe.php seja executável. Talvez você também precise editar o pipe.php para incluir um hashbang na linha 1, que seria algo parecido com: #!/usr/bin/php';
$lang['AdminDepartments.assigned_staff.no_results'] = 'Não há funcionários designados para esse departamento.';
$lang['AdminDepartments.assigned_staff.heading_staff'] = 'Equipe';
$lang['AdminDepartments.assigned_staff.heading_assigned_staff'] = 'Equipe designada';
$lang['AdminDepartments.index.no_results'] = 'Não há departamentos.';
$lang['AdminDepartments.index.confirm_delete'] = 'Os departamentos com tíquetes atribuídos a eles não podem ser excluídos até que todos os tíquetes tenham sido reatribuídos a um departamento alternativo. Tem certeza de que deseja apagar esse departamento?';
$lang['AdminDepartments.index.option_delete'] = 'Excluir';
$lang['AdminDepartments.index.option_edit'] = 'Editar';
$lang['AdminDepartments.index.heading_options'] = 'Opções';
$lang['AdminDepartments.index.heading_default_priority'] = 'Prioridade padrão';
$lang['AdminDepartments.index.heading_assigned_staff'] = 'Equipe designada';
$lang['AdminDepartments.index.heading_email'] = 'E-mail';
$lang['AdminDepartments.index.heading_description'] = 'Descrição';
$lang['AdminDepartments.index.heading_name'] = 'Nome';
$lang['AdminDepartments.index.boxtitle_departments'] = 'Departamentos';
$lang['AdminDepartments.index.categorylink_adddepartment'] = 'Adicionar departamento';
$lang['AdminDepartments.edit.page_title'] = 'Support Manager > Departamentos > Editar departamento';
$lang['AdminDepartments.add.page_title'] = 'Support Manager > Departamentos > Adicionar departamento';
$lang['AdminDepartments.index.page_title'] = 'Gerente de suporte > Departamentos';
$lang['AdminDepartments.!success.department_deleted'] = 'O departamento %1$s foi excluído com sucesso.';
$lang['AdminDepartments.!success.department_updated'] = 'O departamento %1$s foi atualizado com sucesso.';
$lang['AdminDepartments.!success.department_created'] = 'O departamento %1$s foi criado com sucesso.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/pt_br/admin_departments.php <==
<?php
/**
 * Admin Departments
 *
 * @package blesta
 * @subpackage blesta.language.pt_br
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminDepartments.edit.text_add'] = 'Adicionar';
$lang['AdminDepartments.edit.text_delete'] = 'Excluir';
$lang['AdminDepartments.edit.heading_default'] = 'Padrão';
$lang['AdminDepartments.edit.heading_value'] = 'Valor';
$lang['AdminDepartments.edit.heading_name'] = 'Nome';
$lang['AdminDepartments.edit.heading_options'] = 'Opções';
$lang['AdminDepartments.edit.heading_auto_delete'] = 'Auto-Delete (exclusão automática)';
$lang['AdminDepartments.edit.heading_encrypted'] = 'Criptografado';
$lang['AdminDepartments.edit.heading_client_add'] = 'O cliente pode adicionar';
$lang['AdminDepartments.edit.heading_step'] = 'Etapa';
$lang['AdminDepartments.edit.heading_max'] = 'Máximo';
$lang['AdminDepartments.edit.heading_min'] = 'Mínimo';
$lang['AdminDepartments.edit.heading_type'] = 'Tipo';
$lang['AdminDepartments.edit.heading_visibility'] = 'Visibilidade';
$lang['AdminDepartments.edit.heading_description'] = 'Descrição';
$lang['AdminDepartments.edit.heading_label'] = 'Rótulo';
$lang['AdminDepartments.edit.no_results'] = 'Não há campos personalizados nesse departamento.';
$lang['AdminDepartments.edit.confirm_field_remove'] = 'Tem certeza de que deseja excluir esse campo personalizado? Todos os dados associados a esse campo serão excluídos. Se você quiser ocultar esse campo e preservar os dados, altere sua Visibilidade para Staff Only (Somente equipe).';
$lang['AdminDepartments.edit.field_add_field'] = 'Adicionar campo';
$lang['AdminDepartments.edit.field_addsubmit'] = 'Departamento de Edição';
$lang['AdminDepartments.edit.field_status'] = 'Status';
$lang['AdminDepartments.edit.field_response_id'] = 'Resposta de fechamento automático de tíquete';
$lang['AdminDepartments.edit.field_reminder_ticket_priority'] = 'Enviar lembretes para tickets com prioridade';
$lang['AdminDepartments.edit.field_reminder_ticket_status'] = 'Enviar lembretes para tickets com status';
$lang['AdminDepartments.edit.field_reminder_ticket_interval'] = 'Enviar automaticamente lembretes de tíquetes';
$lang['AdminDepartments.edit.field_delete_ticket_interval'] = 'Exclusão automática de tickets';
$lang['AdminDepartments.edit.field_close_ticket_interval'] = 'Fechamento automático de tickets';
$lang['AdminDepartments.edit.field_port'] = 'Porto';
$lang['AdminDepartments.edit.field_pass'] = 'Passe';
$lang['AdminDepartments.edit.field_user'] = 'Usuário';
$lang['AdminDepartments.edit.field_host'] = 'Anfitrião';
$lang['AdminDepartments.edit.field_mark_messages'] = 'Marcar mensagens como';
$lang['AdminDepartments.edit.field_box_name'] = 'Nome da caixa';
$lang['AdminDepartments.edit.field_security'] = 'Segurança';
$lang['AdminDepartments.edit.field_max_attachment_size'] = 'Tamanho máximo do acessório';
$lang['AdminDepartments.edit.field_attachment_types'] = 'Tipos de anexos suportados';
$lang['AdminDepartments.edit.field_include_attachments'] = 'Incluir anexos compatíveis em avisos de tíquetes';
$lang['AdminDepartments.edit.field_default_priority'] = 'Prioridade padrão';
$lang['AdminDepartments.edit.field_piping_config'] = 'Configuração de tubulação';
$lang['AdminDepartments.edit.field_method'] = 'Tratamento de e-mails';
$lang['AdminDepartments.edit.field_automatic_transition'] = 'Transição automática do status do tíquete na resposta do administrador';
$lang['AdminDepartments.edit.field_send_ticket_received'] = 'Enviar e-mails de resposta automática para novos tíquetes';
$lang['AdminDepartments.edit.field_override_from_email'] = 'Substituir o endereço de origem definido nos modelos de e-mail pelo endereço de e-mail definido para esse departamento';
$lang['AdminDepartments.edit.field_email'] = 'E-mail';
$lang['AdminDepartments.edit.field_require_captcha'] = 'Exigir verificação humana para usuários não autenticados';
$lang['AdminDepartments.edit.field_clients_only'] = 'Permitir que apenas clientes abram ou respondam a tíquetes';
$lang['AdminDepartments.edit.field_description'] = 'Descrição';
$lang['AdminDepartments.edit.field_name'] = 'Nome';
$lang['AdminDepartments.edit.tab_custom_fields'] = 'Campos personalizados';
$lang['AdminDepartments.edit.tab_general'] = 'Geral';
$lang['AdminDepartments.edit.boxtitle_adddepartment'] = 'Departamento de Edição';
$lang['AdminDepartments.add.text_add'] = 'Adicionar';
$lang['AdminDepartments.add.text_delete'] = 'Excluir';
$lang['AdminDepartments.add.heading_default'] = 'Padrão';
$lang['AdminDepartments.add.heading_value'] = 'Valor';
$lang['AdminDepartments.add.heading_name'] = 'Nome';
$lang['AdminDepartments.add.heading_options'] = 'Opções';
$lang['AdminDepartments.add.heading_auto_delete'] = 'Auto-Delete (exclusão automática)';
$lang['AdminDepartments.add.heading_encrypted'] = 'Criptografado';
$lang['AdminDepartments.add.heading_client_add'] = 'O cliente pode adicionar';
$lang['AdminDepartments.add.heading_step'] = 'Etapa';
$lang['AdminDepartments.add.heading_max'] = 'Máximo';
$lang['AdminDepartments.add.heading_min'] = 'Mínimo';
$lang['AdminDepartments.add.heading_type'] = 'Tipo';
$lang['AdminDepartments.add.heading_visibility'] = 'Visibilidade';
$lang['AdminDepartments.add.heading_description'] = 'Descrição';
$lang['AdminDepartments.add.heading_label'] = 'Rótulo';
$lang['AdminDepartments.add.field_add_field'] = 'Adicionar campo';
$lang['AdminDepartments.add.field_addsubmit'] = 'Adicionar departamento';
$lang['AdminDepartments.add.field_status'] = 'Status';
$lang['AdminDepartments.add.field_response_id'] = 'Resposta de fechamento automático de tíquete';
$lang['AdminDepartments.add.field_reminder_ticket_priority'] = 'Enviar lembretes para tickets com prioridade';
$lang['AdminDepartments.add.field_reminder_ticket_status'] = 'Enviar lembretes para tickets com status';
$lang['AdminDepartments.add.field_reminder_ticket_interval'] = 'Enviar automaticamente lembretes de tíquetes';
$lang['AdminDepartments.add.field_delete_ticket_interval'] = 'Exclusão automática de tickets';
$lang['AdminDepartments.add.field_close_ticket_interval'] = 'Fechamento automático de tickets';
$lang['AdminDepartments.add.field_port'] = 'Porto';
$lang['AdminDepartments.add.field_pass'] = 'Passe';
$lang['AdminDepartments.add.field_user'] = 'Usuário';
$lang['AdminDepartments.add.field_host'] = 'Anfitrião';
$lang['AdminDepartments.add.field_mark_messages'] = 'Marcar mensagens como';
$lang['AdminDepartments.add.field_box_name'] = 'Nome da caixa';
$lang['AdminDepartments.add.field_security'] = 'Segurança';
$lang['AdminDepartments.add.field_max_attachment_size'] = 'Tamanho máximo do acessório';
$lang['AdminDepartments.add.field_attachment_types'] = 'Tipos de anexos suportados';
$lang['AdminDepartments.add.field_include_attachments'] = 'Incluir anexos compatíveis em avisos de tíquetes';
$lang['AdminDepartments.add.field_default_priority'] = 'Prioridade padrão';
$lang['AdminDepartments.add.field_piping_config'] = 'Configuração de tubulação';
$lang['AdminDepartments.add.field_method'] = 'Tratamento de e-mails';
$lang['AdminDepartments.add.field_automatic_transition'] = 'Transição automática do status do tíquete na resposta do administrador';
$lang['AdminDepartments.add.field_send_ticket_received'] = 'Enviar e-mails de resposta automática para novos tíquetes';
$lang['AdminDepartments.add.field_override_from_email'] = 'Substituir o endereço de origem definido nos modelos de e-mail pelo endereço de e-mail definido para esse departamento';
$lang['AdminDepartments.add.field_email'] = 'E-mail';
$lang['AdminDepartments.add.field_require_captcha'] = 'Exigir verificação humana para usuários não autenticados';
$lang['AdminDepartments.add.field_clients_only'] = 'Permitir que apenas clientes abram ou respondam a tíquetes';
$lang['AdminDepartments.add.field_description'] = 'Descrição';
$lang['AdminDepartments.add.field_name'] = 'Nome';
$lang['AdminDepartments.add.tab_custom_fields'] = 'Campos personalizados';
$lang['AdminDepartments.add.tab_general'] = 'Geral';
$lang['AdminDepartments.add.boxtitle_adddepartment'] = 'Adicionar departamento';
$lang['AdminDepartments.!text.remove_response'] = 'Remover';
$lang['AdminDepartments.!text.no_selected_response'] = 'Nenhuma resposta de fechamento automático foi selecionada.';
$lang['AdminDepartments.!text.add_response'] = 'Definir uma resposta predefinida de fechamento automático';
$lang['AdminDepartments.!tooltip.auto_delete'] = 'Se o tíquete for fechado, os dados do campo serão excluídos automaticamente. Os dados não estarão mais visíveis para a equipe.';
$lang['AdminDepartments.!tooltip.client_add'] = 'Se o cliente pode ou não enviar o campo; se for falso, o cliente só poderá ler o campo.';
$lang['AdminDepartments.!tooltip.max_attachment_size'] = 'Tamanho máximo do anexo a ser incluído em MB.';
$lang['AdminDepartments.!tooltip.attachment_types'] = 'Lista de extensões compatíveis separadas por vírgula (por exemplo, zip, jpg, png).';
$lang['AdminDepartments.!tooltip.include_attachments'] = 'Os servidores de e-mail têm limitações quanto ao tamanho dos anexos e aos tipos de arquivos. Para reduzir o risco de rejeição do e-mail, inclua limitações de tipo e tamanho de anexo. Para ter certeza de que o cliente está ciente dos anexos que não foram incluídos, use a tag {ticket.reply_has_attachments} nos avisos de tíquetes.';
$lang['AdminDepartments.!tooltip.automatic_transition'] = 'Altera o status para %1$s quando um membro da equipe responde.';
$lang['AdminDepartments.!tooltip.send_ticket_received'] = 'A desmarcação dessa caixa indica que os novos tíquetes criados para esse departamento (por e-mail ou cliente) não enviarão um aviso de resposta ao cliente ou à equipe por meio do e-mail Ticket Received (Tíquete recebido) ou do e-mail Staff Ticket Updated (Tíquete da equipe atualizado), respectivamente.';
$lang['AdminDepartments.!tooltip.reminder_ticket_interval'] = 'Para todos os tickets com status diferente de %1$s, um lembrete será enviado para a outra parte se nenhuma resposta for dada dentro do período de tempo selecionado.';
$lang['AdminDepartments.!tooltip.delete_ticket_interval'] = 'Todos os tickets com status de %1$s serão automaticamente apagados após permanecerem nesse status pelo período de tempo selecionado.';
$lang['AdminDepartments.!tooltip.close_ticket_interval'] = 'Todos os tickets com status diferente de %1$s cuja última resposta for de um membro da equipe serão fechados automaticamente se nenhuma resposta for dada dentro do período de tempo selecionado.';
$lang['AdminDepartments.!tooltip.piping_config'] = 'Defina o caminho do piping conforme mostrado, mas certifique-se de usar o caminho correto para o PHP em seu servidor. Certifique-se de que o pipe.php seja executável. Talvez você também precise editar o pipe.php para incluir um hashbang na linha 1, que seria algo parecido com: #!/usr/bin/php';
$lang['AdminDepartments.assigned_staff.no_results'] = 'Não há funcionários designados para esse departamento.';
$lang['AdminDepartments.assigned_staff.heading_staff'] = 'Equipe';
$lang['AdminDepartments.assigned_staff.heading_assigned_staff'] = 'Equipe designada';
$lang['AdminDepartments.index.no_results'] = 'Não há departamentos.';
$lang['AdminDepartments.index.confirm_delete'] = 'Os departamentos com tíquetes atribuídos a eles não podem ser excluídos até que todos os tíquetes tenham sido reatribuídos a um departamento alternativo. Tem certeza de que deseja apagar esse departamento?';
$lang['AdminDepartments.index.option_delete'] = 'Excluir';
$lang['AdminDepartments.index.option_edit'] = 'Editar';
$lang['AdminDepartments.index.heading_options'] = 'Opções';
$lang['AdminDepartments.index.heading_default_priority'] = 'Prioridade padrão';
$lang['AdminDepartments.index.heading_assigned_staff'] = 'Equipe designada';
$lang['AdminDepartments.index.heading_email'] = 'E-mail';
$lang['AdminDepartments.index.heading_description'] = 'Descrição';
$lang['AdminDepartments.index.heading_name'] = 'Nome';
$lang['AdminDepartments.index.boxtitle_departments'] = 'Departamentos';
$lang['AdminDepartments.index.categorylink_adddepartment'] = 'Adicionar departamento';
$lang['AdminDepartments.edit.page_title'] = 'Support Manager > Departamentos > Editar departamento';
$lang['AdminDepartments.add.page_title'] = 'Support Manager > Departamentos > Adicionar departamento';
$lang['AdminDepartments.index.page_title'] = 'Gerente de suporte > Departamentos';
$lang['AdminDepartments.!success.department_deleted'] = 'O departamento %1$s foi excluído com sucesso.';
$lang['AdminDepartments.!success.department_updated'] = 'O departamento %1$s foi atualizado com sucesso.';
$lang['AdminDepartments.!success.department_created'] = 'O departamento %1$s foi criado com sucesso.';
$lang['AdminDepartments.edit.field_priorities'] = 'Prioridades disponíveis';
$lang['AdminDepartments.add.field_priorities'] = 'Prioridades disponíveis';
$lang['AdminDepartments.add.field_force_import'] = 'Forçar importação';
$lang['AdminDepartments.edit.field_force_import'] = 'Forçar importação';
$lang['AdminDepartments.!success.department_imported'] = 'O departamento %1$s foi importado com sucesso.';
